import { defineComponent, toRefs, inject, ref, toRef, computed, resolveComponent, createVNode, mergeProps } from 'vue';

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);

    if (enumerableOnly) {
      symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });
    }

    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function getSlot(slots, exclude) {
  return Object.keys(slots).reduce(function (lst, name) {
    if (!exclude || exclude.indexOf(name) === -1) {
      lst.push(slots[name]);
    }

    return lst;
  }, []);
}

var NAME = 'fcCheckbox';
var Checkbox = defineComponent({
  name: NAME,
  inheritAttrs: false,
  props: {
    modelValue: {
      type: Array,
      "default": function _default() {
        return [];
      }
    },
    type: String
  },
  emits: ['update:modelValue'],
  setup: function setup(props, _) {
    var _toRefs = toRefs(inject('formCreateInject')),
        options = _toRefs.options;

    var trueValue = ref([]);
    var value = toRef(props, 'modelValue');

    var _options = computed(function () {
      return Array.isArray(options) ? options : [];
    });

    var update = function update() {
      trueValue.value = value.value ? _options.value.filter(function (opt) {
        return value.value.indexOf(opt.value) !== -1;
      }).map(function (option) {
        return option.label;
      }) : [];
    };

    update();
    return {
      options: _options,
      trueValue: trueValue,
      value: value,
      onInput: function onInput(n) {
        _.emit('update:modelValue', _options.value.filter(function (opt) {
          return n.indexOf(opt.label) !== -1;
        }).map(function (opt) {
          return opt.value;
        }).filter(function (v) {
          return v !== undefined;
        }));
      },
      update: update
    };
  },
  watch: {
    modelValue: function modelValue() {
      this.update();
    }
  },
  render: function render() {
    var _this$$slots$default,
        _this$$slots,
        _this = this;

    var name = this.type === 'button' ? 'ElCheckboxButton' : 'ElCheckbox';
    var Type = resolveComponent(name);
    return createVNode(resolveComponent("ElCheckboxGroup"), mergeProps(this.$attrs, {
      "modelValue": this.trueValue,
      "onUpdate:modelValue": this.onInput
    }), _objectSpread2({
      "default": function _default() {
        return [_this.options.map(function (opt, index) {
          var props = _objectSpread2({}, opt);

          delete props.value;
          return createVNode(Type, mergeProps(props, {
            "key": name + index + opt.value
          }), null);
        }), (_this$$slots$default = (_this$$slots = _this.$slots)["default"]) === null || _this$$slots$default === void 0 ? void 0 : _this$$slots$default.call(_this$$slots)];
      }
    }, getSlot(this.$slots, ['default'])));
  }
});

export { Checkbox as default };
